@@ -1,5 +1,5 @@
 __all__ = ["pSock"]
-__version__ = "1.2.7"
+__version__ = "1.3.0"
 
 # -*- coding: utf-8 -*-
 
@@ -94,7 +94,7 @@ class Web:
         elif type(classandid) == dict:
             for element in elements:
                 try:
-                    soup.find(element, classandid)
+                    finded = soup.find(element, classandid)
                 except:
                     pass
             return finded
@@ -140,7 +140,6 @@ class Net:
             self.sock.connect((str(self.ip), int(self.port)))
         else:
             self.ip, self.port = Address[0], Address[1]
-            print((str(self.ip)+ str(self.port)))
             self.sock.connect((str(self.ip), int(self.port)))
         self.connection = True
         self.netargs = True
@@ -195,7 +194,7 @@ class Net:
             connection = self.sock
         tosend = str(content).encode(str(codify))
         ip, port = address[0], address[1]
-        connection.sendto(tosend, (ip, port))
+        connection.sendto(tosend, (ip, port))    
 
     def send(self, content, connection = None, codify = "utf-8"):
         if connection == None:
